==> nektar%2B%2B-5.7.0.tar.xz: nektar-v5.7.0/library/LibUtilities/Python/BasicUtils/ShapeType.cpp <==
////////////////////////////////////////////////////////////////////////////////
//
//  File: ShapeType.cpp
//
//  For more information, please see: http://www.nektar.info/
//
//  The MIT License
//
//  Copyright (c) 2006 Division of Applied Mathematics, Brown University (USA),
//  Department of Aeronautics, Imperial College London (UK), and Scientific
//  Computing and Imaging Institute, University of Utah (USA).
//
//  Permission is hereby granted, free of charge, to any person obtaining a
//  copy of this software and associated documentation files (the "Software"),
//  to deal in the Software without restriction, including without limitation
//  the rights to use, copy, modify, merge, publish, distribute, sublicense,
//  and/or sell copies of the Software, and to permit persons to whom the
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included
//  in all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
//  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//  DEALINGS IN THE SOFTWARE.
//
//  Description: Python wrapper for ShapeType.
//
////////////////////////////////////////////////////////////////////////////////

#include <LibUtilities/BasicUtils/ShapeType.hpp>
#include <LibUtilities/Python/NekPyConfig.hpp>
#include <vector>

using namespace Nektar::LibUtilities;

/**
 * @brief Export for ShapeType enumeration.
 */
void export_ShapeType()
{
    NEKPY_WRAP_ENUM(ShapeType, ShapeTypeMap)
}

==> nektar%2B%2B-5.8.0.tar.xz: nektar-v5.8.0/library/LibUtilities/Python/BasicUtils/ShapeType.cpp <==
////////////////////////////////////////////////////////////////////////////////
//
//  File: ShapeType.cpp
//
//  For more information, please see: http://www.nektar.info/
//
//  The MIT License
//
//  Copyright (c) 2006 Division of Applied Mathematics, Brown University (USA),
//  Department of Aeronautics, Imperial College London (UK), and Scientific
//  Computing and Imaging Institute, University of Utah (USA).
//
//  Permission is hereby granted, free of charge, to any person obtaining a
//  copy of this software and associated documentation files (the "Software"),
//  to deal in the Software without restriction, including without limitation
//  the rights to use, copy, modify, merge, publish, distribute, sublicense,
//  and/or sell copies of the Software, and to permit persons to whom the
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included
//  in all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
//  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//  DEALINGS IN THE SOFTWARE.
//
//  Description: Python wrapper for ShapeType.
//
////////////////////////////////////////////////////////////////////////////////

#include <LibUtilities/BasicUtils/ShapeType.hpp>
#include <LibUtilities/Python/NekPyConfig.hpp>
#include <vector>

using namespace Nektar::LibUtilities;

/**
 * @brief Export for ShapeType enumeration.
 */
void export_ShapeType(py::module &m)
{
    NEKPY_WRAP_ENUM(m, ShapeType, ShapeTypeMap)
}
